2023-09-25 Version: 1.5.0
- Support DIJob and DIAlarmRule related APIs.

2023-09-19 Version: 1.4.0
- Generated python2 2020-05-18 for dataworks-public.

2023-08-10 Version: 1.3.0
- Generated python2 2020-05-18 for dataworks-public.

2023-07-25 Version: 1.2.12
- Generated python2 2020-05-18 for dataworks-public.

2023-07-17 Version: 1.2.11
- Generated python2 2020-05-18 for dataworks-public.

2023-06-12 Version: 1.2.10
- Generated python2 2020-05-18 for dataworks-public.

2023-06-05 Version: 1.2.9
- Generated python2 2020-05-18 for dataworks-public.

2023-03-31 Version: 1.2.8
- Generated python2 2020-05-18 for dataworks-public.

2023-03-16 Version: 1.2.7
- Generated python2 2020-05-18 for dataworks-public.

2023-03-08 Version: 1.2.6
- Generated python2 2020-05-18 for dataworks-public.

2023-03-07 Version: 1.2.5
- Generated python2 2020-05-18 for dataworks-public.

2023-03-07 Version: 1.2.4
- Generated python2 2020-05-18 for dataworks-public.

2023-03-02 Version: 1.2.3
- Generated python2 2020-05-18 for dataworks-public.

2023-03-02 Version: 1.2.2
- Generated python2 2020-05-18 for dataworks-public.

2023-02-09 Version: 1.2.1
- Generated python2 2020-05-18 for dataworks-public.

2023-01-13 Version: 1.2.0
- Generated python2 2020-05-18 for dataworks-public.

2023-01-05 Version: 1.1.23
- Generated python2 2020-05-18 for dataworks-public.

2022-12-23 Version: 1.1.22
- Generated python2 2020-05-18 for dataworks-public.

2022-12-22 Version: 1.1.21
- Generated python2 2020-05-18 for dataworks-public.

2022-12-16 Version: 1.1.20
- Generated python2 2020-05-18 for dataworks-public.

2022-12-02 Version: 1.1.19
- Generated python2 2020-05-18 for dataworks-public.

2022-12-02 Version: 1.1.18
- Generated python2 2020-05-18 for dataworks-public.

2022-11-16 Version: 1.1.17
- Generated python2 2020-05-18 for dataworks-public.

2022-10-13 Version: 1.1.16
- Generated python2 2020-05-18 for dataworks-public.

2022-08-31 Version: 1.1.15
- Generated python2 2020-05-18 for dataworks-public.

2022-08-11 Version: 1.1.14
- Generated python2 2020-05-18 for dataworks-public.

2022-07-20 Version: 1.1.13
- Generated python2 2020-05-18 for dataworks-public.

2022-07-19 Version: 1.1.12
- Generated python2 2020-05-18 for dataworks-public.

2022-05-30 Version: 1.1.11
- Generated python2 2020-05-18 for dataworks-public.

2022-05-10 Version: 1.1.10
- Generated python2 2020-05-18 for dataworks-public.

2022-05-07 Version: 1.1.9
- Generated python2 2020-05-18 for dataworks-public.

2022-04-25 Version: 1.1.8
- Generated python2 2020-05-18 for dataworks-public.

2022-04-19 Version: 1.1.7
- Generated python2 2020-05-18 for dataworks-public.

2022-04-07 Version: 1.1.6
- Generated python2 2020-05-18 for dataworks-public.

2022-03-21 Version: 1.1.5
- Generated python2 2020-05-18 for dataworks-public.

2022-02-28 Version: 1.1.4
- Generated python2 2020-05-18 for dataworks-public.

2021-12-06 Version: 1.1.3
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.2
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.1
- Generated python2 2020-05-18 for dataworks-public.

2021-09-10 Version: 1.1.0
- Generated python2 2020-05-18 for dataworks-public.

2021-08-20 Version: 1.0.1
- Generated python2 2020-05-18 for dataworks-public.

2021-05-20 Version: 1.0.0
- Generated python2 2020-05-18 for dataworks-public.

